scxpand.pretrained.model\_registry
==================================

.. automodule:: scxpand.pretrained.model_registry

   
   .. rubric:: Functions

   .. autosummary::
   
      get_pretrained_model_info
   
   .. rubric:: Classes

   .. autosummary::
   
      PretrainedModelInfo
   